from myproject.conf.settings import *

DEBUG = True
TEMPLATE_DEBUG = DEBUG

ADMINS = (
    ('You', 'your@email'),
)
MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(VAR_ROOT, 'dev.db'),
    }
}

ROOT_URLCONF = '%s.conf.local.urls' % PROJECT_MODULE_NAME

INSTALLED_APPS += (
    'django.contrib.admin',
    'django.contrib.admindocs',
)



# This file will contain
# - a description of this project template
# - the list of variables to be substituted
# - the commands to be launched after copying the template files (e.g. git pull)

# Also, this file will NOT be copied


from datetime import datetime
from django.utils.html import strip_tags, urlize
from django.contrib import admin
from django.contrib.humanize.templatetags import humanize
from django.contrib.contenttypes.models import ContentType
from django.conf import settings
from models import XXXMODEL_NAMEXXX

def view_on_site(XXXVAR_NAMEXXX):
    '''Return a link to view the XXXVAR_NAMEXXX on site.'''
    type_id = ContentType.objects.get_for_model(XXXMODEL_NAMEXXX).id
    caption = XXXVAR_NAMEXXX.get_absolute_url()
    return '<a href="../../r/%s/%s/">%s</a>' % (type_id, XXXVAR_NAMEXXX.id, caption)
view_on_site.short_description = 'Preview'
view_on_site.allow_tags = True

def content_excerpt(XXXVAR_NAMEXXX, length = 90):
    '''Return the content truncated to the first [length] characters.'''
    text = strip_tags(XXXVAR_NAMEXXX.content)
    return text[:length] + '...' if len(text) > length else text
content_excerpt.short_description = 'Excerpt'

def human_published_on(XXXVAR_NAMEXXX):
    '''Return the humanized version of the published_on date.'''
    return humanize.naturalday(XXXVAR_NAMEXXX.published_on)
human_published_on.short_description = 'Published on'

class XXXMODEL_NAMEXXXAdmin(admin.ModelAdmin):
    # A list of actions to make available on the change list page.
    actions = ['publish_now']
    # Include a date-based drilldown navigation by that field.
    date_hierarchy = 'published_on'
    # A list of field names to exclude from the form.
    exclude = None
    # Control the layout of admin "add" and "change" pages.
    fieldsets = None
    # Control which fields are displayed on the change list page.
    list_display = ('__unicode__', human_published_on,
      content_excerpt, view_on_site, )
    # Activate filters in the right sidebar of the change list page.
    list_filter = ['published_on',]
    # Override model's ordering to specify how objects should be ordered. 
    ordering = None
    # A dictionary mapping field names to the fields it should prepopulate from
    prepopulated_fields = {'slug': ('title',)}
    # A list of field names that will be searchable in the change list page.
    search_fields = ['title','content',]

    class Media:
        relative_paths = ['tinymce/jscripts/tiny_mce/tiny_mce.js', 
          'tinymce_setup/tinymce_setup.js',]
        js = [settings.ADMIN_MEDIA_PREFIX + file for file in relative_paths] 
    
    def publish_now(self, request, queryset):
        rows_updated = queryset.filter(published_on__isnull=True).update(
            published_on=datetime.now())
        if rows_updated == 1: message_bit = "1 XXXSINGULARXXX was"
        else: message_bit = "%s XXXPLURALXXX were" % rows_updated
        self.message_user(request, "%s successfully published." % message_bit)
    publish_now.short_description = "Publish now"

admin.site.register(XXXMODEL_NAMEXXX, XXXMODEL_NAMEXXXAdmin)



#!/usr/bin/env python
import os
import sys
from django import get_version
from django.core.management import execute_from_command_line, LaxOptionParser
from django.core.management.base import BaseCommand

# Work out the project module name and root directory, assuming that this file
# is located at [project]/bin/manage.py
PROJECT_DIR, PROJECT_MODULE_NAME = os.path.split(
                os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

# Check that the project module can be imported.
try:
    __import__(PROJECT_MODULE_NAME)
except ImportError:
    # Couldn't import the project, place it on the Python path and try again.
    sys.path.append(PROJECT_DIR)
    try:
        __import__(PROJECT_MODULE_NAME)
    except ImportError:
        sys.stderr.write("Error: Can't import the \"%s\" project module." %
                         PROJECT_MODULE_NAME)
        sys.exit(1)

def has_settings_option():
    parser = LaxOptionParser(usage="%prog subcommand [options] [args]",
                             version=get_version(),
                             option_list=BaseCommand.option_list)
    try:
        options = parser.parse_args(sys.argv[:])[0]
    except:
        return False # Ignore any option errors at this point.
    return bool(options.settings)

if not has_settings_option() and not 'DJANGO_SETTINGS_MODULE' in os.environ:
    settings_module = '%s.conf.local.settings' % PROJECT_MODULE_NAME
    os.environ['DJANGO_SETTINGS_MODULE'] = settings_module

execute_from_command_line()



# This context processor allows templates to simply access Django settings
# For exaxmple: {% if settings.ENVIRONMENT == 'development' %} {% endif %}
from django.conf import settings as _settings

def settings(request):
    return {'settings': _settings}


from django.conf.urls.defaults import *
from models import Post
from feeds import PostsFeed

urlpatterns = patterns('posts.views',
    (r'^/$', 'index', {}, 'posts'),
    (r'^feed/$', PostsFeed(), {}, 'posts-feed'),
    (r'^(?P<post_slug>.+)/$', 'show', {}, 'post'),
)



# Run python manage.py server to run the server in a given environment

from django.core.management.base import BaseCommand, CommandError
from django.core.management import call_command
from os import system, environ        
import logging

class Command(BaseCommand):
    help = "Call runserver with a given environment after removing .pyc files."

    def handle(self, *args, **options):
        """
        Call runserver with a given environment after removing .pyc files.
        """
        system('find . -type f -name "*.pyc" -delete;')
        call_command('runserver', '0.0.0.0:8000')
        logging.info("Server success")





from django.conf.urls.defaults import patterns, include
from django.contrib import admin

admin.autodiscover()

urlpatterns = patterns('',
    (r'^admin/doc/', include('django.contrib.admindocs.urls')),
    (r'^admin/', include(admin.site.urls)),
)



from django.conf.urls.defaults import patterns, include
from django.conf.urls.static import static
from django.conf import settings

CONF_MODULE = '%s.conf' % settings.PROJECT_MODULE_NAME

urlpatterns = patterns('',
    (r'', include('%s.urls' % CONF_MODULE)),
    (r'', include('%s.common.urls.admin' % CONF_MODULE)),
)
if settings.MEDIA_ROOT:
    urlpatterns += static(settings.MEDIA_URL,
                          document_root=settings.MEDIA_ROOT)



import os, sys
from shutil import copytree, ignore_patterns
from optparse import make_option
from django_start.management.base import BaseCommand, CommandError

class Command(BaseCommand):
    help = """Create a Django project from a template.
    
    The template must include a file called `django_start.py` that contains
    the documentation for the template, the optional boilerplate variables
    to substitute with prompt values and the actions to perform after having
    copied the template files (e.g., importing more files with git)."""

    args = "[project_folder]"

    TEMPLATE_DIR = os.path.join(os.path.dirname(__file__), 
        '..', '..', 'templates', 'project', 'ff0000')

    option_list = BaseCommand.option_list + (make_option('--template-dir', 
        action='store', default=TEMPLATE_DIR, help='Project template to use'),)

    def handle(self, *args, **options):
        if len(args) != 1:
            raise CommandError('Indicate the folder name for the project.')
        # 1. Copy the template folder
        copy_from = options['template_dir']
        copy_to = args[0]
        copytree(copy_from, copy_to, ignore=ignore_patterns('django_start*',))
        # 2. If template has a settings file, run its after_copy method
        settings_path = os.path.join(copy_from, 'django_start_settings.py')
        if os.path.exists(settings_path):
            sys.path.append(copy_from)
            import django_start_settings
            if callable(getattr(django_start_settings, 'after_copy', None)):
                # First change current directory to copy_to
                os.chdir(copy_to)
                no_prompt = options.get('no_prompt', False)
                django_start_settings.after_copy(no_prompt=no_prompt)
            
        


import os
import sys
from django.conf import settings

# Prevent interactive question about wanting a superuser created
# since the admin user is already created through the initial data
# (taken from http://stackoverflow.com/questions/1466827/)
from django.db.models import signals
from django.contrib.auth.management import create_superuser
from django.contrib.auth import models as auth_app
signals.post_syncdb.disconnect(create_superuser, sender=auth_app,
    dispatch_uid = "django.contrib.auth.management.create_superuser")

if settings.DEBUG:
    # Load host-specific configuration file from hosts/[hostname].py
    from socket import gethostname # Hostname based local settings 
    hostname = gethostname().split('.')[0]
    try:
        _f = __file__              
        path = os.path.join(settings.PROJECT_ROOT, 'settings')
        sys.path.insert(0, path)   
        globals().update(__import__(hostname).__dict__)
        sys.path.remove(path)      
        __file__ = _f              
    except ImportError, e: 
        print >> sys.stderr, '[33mLocal settings file: [[34msettings/%s.py[33m] error:[0m\n%s' % (hostname,e)



import os
from optparse import make_option
from django_start.management.base import BaseCommand, CommandError
from django_start.management.utils import copy_template, camelcase_to_underscore


class Command(BaseCommand):
    help = """
        Create a Django app from a template, replacing boilerplate variables.
        Also adds the app to INSTALLED_APPS and register its urls."""
    args = "[project_folder]"

    TEMPLATE_DIR = os.path.join(os.path.dirname(__file__), 
        '..', '..', 'templates', 'app', 'blog')

    option_list = BaseCommand.option_list + (
        make_option('--template-dir', action='store', default=TEMPLATE_DIR, 
            help='Project template directory to use.'),)


    def handle(self, *args, **options):
        if len(args) != 1:
            raise CommandError('Indicate the folder name for the app.')

        placemarks = [
            ['MODEL_NAME', 'Model Name', None],
        ]

        src = options['template_dir']
        project_folder = args[0]
        replace = {}
        for var, help, default in placemarks:
            placemark = 'XXX%sXXX' % var
            replace[placemark] = None
            while not replace[placemark]:
                prompt = '%s [%s]: ' % (help, default)
                replace[placemark] = raw_input(prompt) or default
        # Now add some placemarks based on other ones
        replace['XXXFOLDERXXX'] = project_folder
        # if MODEL_NAME: BlogPost then VAR_NAME: blog_post
        replace['XXXVAR_NAMEXXX'] = camelcase_to_underscore(replace['XXXMODEL_NAMEXXX'])
        replace['XXXSINGULARXXX'] = replace['XXXVAR_NAMEXXX'].replace('_', ' ')
        replace['XXXPLURALXXX'] = '%ss' % replace['XXXSINGULARXXX']
        copy_template("%s/apps" % src, "apps/%s" % project_folder, replace)
        copy_template("%s/templates" % src, "templates/%s" % project_folder, replace)
        print "Application %s created. To activate:" % replace['XXXMODEL_NAMEXXX']
        print "- Add this line to INSTALLED_APPS in your project settings file:"
        print "\t'%s'," % project_folder
        print "- Add this line to urlpatterns in your project urls file:"
        print "\t(r'^%s/', include('%s.urls'))," % (project_folder, project_folder)
        print "- Synchronize the database"


# Run python manage.py reset_db to start from afresh then do a sync.
# Original code by dnordberg at http://djangosnippets.org/snippets/828/

from django.conf import settings
from django.core.management.base import CommandError
import logging
from django.core.management.base import BaseCommand
from django.db import connection
        
class Command(BaseCommand):
    help = "Resets a database."

    def handle(self, *args, **options):
        """
        Resets a database.
        """
        database = settings.DATABASES['default']
        if 'sqlite3' in database['ENGINE']:
            import os
            try:
                logging.info("Unlinking sqlite3 database")
                os.unlink(database['NAME'])
            except OSError:
                pass
        elif 'mysql' in database['ENGINE']:
            import MySQLdb as Database
            kwargs = {
                'user': database['USER'],
                'passwd': database['PASSWORD'],
            }
            if database['HOST'].startswith('/'):
                kwargs['unix_socket'] = database['HOST']
            else:
                kwargs['host'] = database['HOST']
            if database['PORT']:
                kwargs['port'] = int(database['PORT'])
            connection = Database.connect(**kwargs)
            drop_query = 'DROP DATABASE IF EXISTS %s' % database['NAME']
            create_query = 'CREATE DATABASE %s' % database['NAME']
            logging.info('Executing... "' + drop_query + '"')
            connection.query(drop_query)
            logging.info('Executing... "' + create_query + '"')
            connection.query(create_query)
        elif 'postgresql' in database['ENGINE']:
            if 'postgresql_psycopg2' in database['ENGINE']:
                import psycopg2 as Database
            else:
                import psycopg as Database
    
            if database['NAME'] == '':
                from django.core.exceptions import ImproperlyConfigured
                raise ImproperlyConfigured, "You need to specify DATABASE_NAME in your Django settings file."
            if database['USER']:
                conn_string = "user=%s" % (database['USER'])
            if database['PASSWORD']:
                conn_string += " password='%s'" % database['PASSWORD']
            if database['HOST']:
                conn_string += " host=%s" % database['HOST']
            if database['PORT']:
                conn_string += " port=%s" % database['PORT']
            connection = Database.connect(conn_string)
            connection.set_isolation_level(0) #autocommit false
            cursor = connection.cursor()
            drop_query = 'DROP DATABASE %s' % database['NAME']
            logging.info('Executing... "' + drop_query + '"')
    
            try:
                cursor.execute(drop_query)
            except Database.ProgrammingError, e:
                logging.info("Error: "+str(e))
    
            # Encoding should be SQL_ASCII (7-bit postgres default) or prefered UTF8 (8-bit)
            create_query = ("""
CREATE DATABASE %s
    WITH OWNER = %s
        ENCODING = 'UTF8'
        TABLESPACE = pg_default;
""" % (database['NAME'], database['USER']))
            logging.info('Executing... "' + create_query + '"')
            cursor.execute(create_query)
    
        else:
            raise CommandError, "Unknown database engine %s" % database['ENGINE']
    
        logging.info("Reset success")



#!/usr/bin/env python
from django.core.management import execute_manager
import sys, os.path
try:
    import settings # Assumed to be in the same directory.
except ImportError:
    import sys
    sys.stderr.write("[33mHelp! [[34msettings.py[33m] is gone![0m\\n")
    sys.exit(1)

if __name__ == "__main__":
    execute_manager(settings)



# Copyright (c) 2009, Sunlight Foundation
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
# 
#     * Redistributions of source code must retain the above copyright notice,
#       this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright notice,
#       this list of conditions and the following disclaimer in the documentation
#       and/or other materials provided with the distribution.
#     * Neither the name of Sunlight Foundation, Sunlight Labs
#       nor the names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from django.conf import settings
from django.core.exceptions import MiddlewareNotUsed
from django.utils.decorators import decorator_from_middleware
	
CONTENT_TYPES = ('text/html','application/xhtml+xml','application/xml')
HEADER_VALUE = getattr(settings, 'X_UA_COMPATIBLE', 'IE=edge,chrome=1')

class XUACompatibleMiddleware(object):
    
    def __init__(self, value=None):
        
        self.value = value
        if value is None:
            self.value = HEADER_VALUE
        if not self.value:
            raise MiddlewareNotUsed
        
    def process_response(self, request, response):
        response_ct = response.get('Content-Type','').split(';', 1)[0].lower()
        if response_ct in CONTENT_TYPES:
            if not 'X-UA-Compatible' in response:
                response['X-UA-Compatible'] = self.value
        return response

xuacompatible = decorator_from_middleware(XUACompatibleMiddleware)

# Strip Google Analytics cookies for caching middleware purposes
# From http://djangosnippets.org/snippets/1772/
# Author: nf / nf@wh3rd.net

import re

class StripCookieMiddleware(object):
    strip_re = re.compile(r'(__utm.=.+?(?:; |$))')
    def process_request(self, request):
        try:
            cookie = self.strip_re.sub('', request.META['HTTP_COOKIE'])
            request.META['HTTP_COOKIE'] = cookie
        except: pass


#!/usr/bin/env python
from setuptools import setup, find_packages

setup(name='myproject',
      version='0.1',
      packages=find_packages(),
      package_data={'myproject': ['bin/*.*', 'static/*.*', 'templates/*.*']},
      exclude_package_data={'myproject': ['bin/*.pyc']},
      scripts=['myproject/bin/manage.py'])



from django.conf.urls.defaults import *
from models import XXXMODEL_NAMEXXX
from feeds import XXXMODEL_NAMEXXXFeed

urlpatterns = patterns('XXXFOLDERXXX.views',
    (r'^$', 'index', {}, 'XXXVAR_NAMEXXXs'),
    (r'^(?P<XXXVAR_NAMEXXX_slug>.+)/$', 'show', {}, 'XXXVAR_NAMEXXX'),
    (r'^feed/$', XXXMODEL_NAMEXXXFeed(), {}, 'XXXVAR_NAMEXXXs-feed'),
)



from django.contrib.syndication.views import Feed
from django.core.urlresolvers import reverse
from models import Post

class PostsFeed(Feed):
    title = "XXXPROJECT_NAMEXXX &mdash; Posts"
    description = "Latest posts from XXXPROJECT_NAMEXXX"

    def link(self, obj): return reverse('posts')

    def items(self):
        return Post.objects.published()[:5]

    def item_title(self, item):
        return item.title

    def item_description(self, item):
        return item.content


from myproject.conf.settings import *

DEBUG = False
TEMPLATE_DEBUG = DEBUG

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    }
}
ROOT_URLCONF = 'myproject.conf.test.urls'

INSTALLED_APPS += ('django_nose',)

TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'



from settings import *

DEBUG = False

ENVIRONMENT = 'production' # admin links will be red

# Indicate your database settings for production here
#
# DATABASES = {
#     'default': {
#         'NAME': '',
#         'ENGINE': 'django.db.backends.mysql',
#         'USER': '',
#         'PASSWORD': '',
#         'HOST': ''
#     }
# }




from myproject.conf.settings import *

DEBUG = True
TEMPLATE_DEBUG = DEBUG

ROOT_URLCONF = 'myproject.conf.dev.urls'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': 'myproject',
#        'USER': 'dbuser',
#        'PASSWORD': 'dbpassword',
    }
}

INSTALLED_APPS += (
    'django.contrib.admin',
    'django.contrib.admindocs',
)



import os
import sys
from optparse import OptionParser
from django_start.management.base import BaseCommand, CommandError
from django_start.management.importlib import import_module

# A cache of loaded commands, so that call_command doesn't have to reload
_commands = None

def get_commands():
    """
    Returns a dictionary mapping command names to their callback applications.

    The dictionary is cached on the first call and reused on subsequent
    calls.
    """
    global _commands
    if _commands is None:
        command_dir = os.path.join(__path__[0], 'commands')
        try:
            _commands = [f[:-3] for f in os.listdir(command_dir)
                    if not f.startswith('_') and f.endswith('.py')]
        except OSError:
            _commands = []
    return _commands


class ManagementUtility(object):
    """
    Encapsulates the logic of the django-admin.py and manage.py utilities.

    A ManagementUtility has a number of commands, which can be manipulated
    by editing the self.commands dictionary.
    """
    def __init__(self, argv=None):
        self.argv = argv or sys.argv[:]
        self.prog_name = os.path.basename(self.argv[0])

    def main_help_text(self):
        """
        Returns the script's main help text, as a string.
        """
        usage = ['',"Type '%s help <subcommand>' for help on a specific subcommand." % self.prog_name,'']
        usage.append('Available subcommands:')
        commands = get_commands()
        commands.sort()
        for cmd in commands:
            usage.append('  %s' % cmd)
        return '\n'.join(usage)

    def fetch_command(self, subcommand):
        """
        Tries to fetch the given subcommand, printing a message with the
        appropriate command called from the command line if it can't be found.
        """
        if not subcommand in get_commands():
            sys.stderr.write("Unknown command: %r\nType '%s help' for usage.\n" % \
                (subcommand, self.prog_name))
            sys.exit(1)
        module = import_module('django_start.management.commands.%s' % subcommand)
        klass = module.Command()
        return klass

    def execute(self):
        """
        Given the command-line arguments, this figures out which subcommand is
        being run, creates a parser appropriate to that command, and runs it.
        """
        # These options could affect the commands that are available, so they
        # must be processed early.
        parser = OptionParser(usage="%prog subcommand [options] [args]",
                                 option_list=BaseCommand.option_list)
        try:
            options, args = parser.parse_args(self.argv)
        except:
            pass # Ignore any option errors at this point.

        try:
            subcommand = self.argv[1]
        except IndexError:
            subcommand = 'help' # Display help if no arguments were given.

        if subcommand == 'help':
            if len(args) > 2:
                self.fetch_command(args[2]).print_help(self.prog_name, args[2])
            else:
                parser.print_help()
                sys.stderr.write(self.main_help_text() + '\n')
                sys.exit(1)
        elif self.argv[1:] in (['--help'], ['-h']):
            parser.print_help()
            sys.stderr.write(self.main_help_text() + '\n')
        else:
            self.fetch_command(subcommand).run_from_argv(self.argv)


def execute_from_command_line(argv=None):
    """
    A simple method that runs a ManagementUtility.
    """
    utility = ManagementUtility(argv)
    utility.execute()




from fabric.api import env, local, run, require, cd
from fabric.operations import _prefix_commands, _prefix_env_vars

env.disable_known_hosts = True # always fails for me without this
env.hosts = ['myproject.mydevhost']
env.root = '/opt/webapps/myproject'
env.proj_root = env.root + '/src/myproject'
env.proj_repo = 'git@github.com:myuser/myrepo.git'
env.pip_file = env.proj_root + '/requirements.pip'


def deploy():
    """Update source, update pip requirements, syncdb, restart server"""
    update()
    update_reqs()
    syncdb()
    restart()


def switch(branch):
    """Switch the repo branch which the server is using"""
    with cd(env.proj_root):
        ve_run('git checkout %s' % branch)
    restart()


def version():
    """Show last commit to repo on server"""
    with cd(env.proj_root):
        sshagent_run('git log -1')


def restart():
    """Restart Apache process"""
    run('touch %s/etc/apache/django.wsgi' % env.root)


def update_reqs():
    """Update pip requirements"""
    ve_run('yes w | pip install -r %s' % env.pip_file)


def update():
    """Updates project source"""
    with cd(env.proj_root):
        sshagent_run('git pull')


def syncdb():
    """Run syncdb (along with any pending south migrations)"""
    ve_run('manage.py syncdb --migrate')


def clone():
    """Clone the repository for the first time"""
    with cd('%s/src' % env.root):
        sshagent_run('git clone %s' % env.proj_repo)
    ve_run('pip install -e %s' % env.proj_root)
    
    with cd('%s/myproject/conf/local' % env.proj_root):
        run('ln -s ../dev/__init__.py')
        run('ln -s ../dev/settings.py')


def ve_run(cmd):
    """
    Helper function.
    Runs a command using the virtualenv environment
    """
    require('root')
    return sshagent_run('source %s/bin/activate; %s' % (env.root, cmd))


def sshagent_run(cmd):
    """
    Helper function.
    Runs a command with SSH agent forwarding enabled.

    Note:: Fabric (and paramiko) can't forward your SSH agent.
    This helper uses your system's ssh to do so.
    """
    # Handle context manager modifications
    wrapped_cmd = _prefix_commands(_prefix_env_vars(cmd), 'remote')
    try:
        host, port = env.host_string.split(':')
        return local(
            "ssh -p %s -A %s@%s '%s'" % (port, env.user, host, wrapped_cmd)
        )
    except ValueError:
        return local(
            "ssh -A %s@%s '%s'" % (env.user, env.host_string, wrapped_cmd)
        )



from django.conf import settings
from django.db import models
from datetime import datetime
from utils import current_time

class XXXMODEL_NAMEXXXManager(models.Manager):
    def published(self):
        return self.filter(published_on__lte=datetime.now())

class XXXMODEL_NAMEXXX(models.Model):
    objects         = XXXMODEL_NAMEXXXManager()
    title           = models.CharField(max_length=255, help_text=
        "Title of the XXXSINGULARXXX (max 255 characters)")
    slug            = models.SlugField(help_text=
        "URL component that identifies the XXXSINGULARXXX")
    content         = models.TextField(help_text=
        "Body of the XXXSINGULARXXX")
    published_on    = models.DateTimeField(null=True, blank=True, 
      default       = datetime.now(), help_text= 
      "Any XXXSINGULARXXX with empty or future date will not appear in the blog.\n" +
      "Current %s time is: %s.<br>" % (settings.TIME_ZONE, current_time))


    class Meta:
        ordering = ['-published_on',]
        
    def __unicode__(self): 
        return self.title

    @models.permalink
    def get_absolute_url(self):
        return ('XXXVAR_NAMEXXX', (), {'XXXVAR_NAMEXXX_slug': self.slug})
    



from settings import *

ENVIRONMENT = 'staging' # admin links will be orange

# Indicate your database settings for staging here
#
# DATABASES = {
#     'default': {
#         'NAME': '',
#         'ENGINE': 'django.db.backends.mysql',
#         'USER': '',
#         'PASSWORD': '',
#         'HOST': ''
#     }
# }




"""
Base classes for writing django_start management commands.
"""

import os
import sys
from optparse import make_option, OptionParser

class CommandError(Exception):
    """
    Exception class indicating a problem while executing a management
    command.

    If this exception is raised during the execution of a management
    command, it will be caught and turned into a nicely-printed error
    message to the appropriate output stream (i.e., stderr); as a
    result, raising this exception (with a sensible description of the
    error) is the preferred way to indicate that something has gone
    wrong in the execution of a command.

    """
    pass

class BaseCommand(object):
    """
    The base class from which all management commands ultimately
    derive.

    Use this class if you want access to all of the mechanisms which
    parse the command-line arguments and work out what code to call in
    response; if you don't need to change any of that behavior,
    consider using one of the subclasses defined in this file.

    If you are interested in overriding/customizing various aspects of
    the command-parsing and -execution behavior, the normal flow works
    as follows:

    1. ``django-admin.py`` or ``manage.py`` loads the command class
       and calls its ``run_from_argv()`` method.

    2. The ``run_from_argv()`` method calls ``create_parser()`` to get
       an ``OptionParser`` for the arguments, parses them, performs
       any environment changes requested by options, and then calls the
       ``execute()`` method, passing the parsed arguments.

    3. The ``execute()`` method attempts to carry out the command by
       calling the ``handle()`` method with the parsed arguments; any
       output produced by ``handle()`` will be printed to standard
       output and, if the command is intended to produce a block of
       SQL statements, will be wrapped in ``BEGIN`` and ``COMMIT``.

    4. If ``handle()`` raised a ``CommandError``, ``execute()`` will
       instead print an error message to ``stderr``.

    Thus, the ``handle()`` method is typically the starting point for
    subclasses; many built-in commands and command types either place
    all of their logic in ``handle()``, or perform some additional
    parsing work in ``handle()`` and then delegate from it to more
    specialized methods as needed.

    Several attributes affect behavior at various steps along the way:

    ``args``
        A string listing the arguments accepted by the command,
        suitable for use in help messages; e.g., a command which takes
        a list of application names might set this to '<appname
        appname ...>'.

    ``help``
        A short description of the command, which will be printed in
        help messages.

    """
    # Metadata about this command.
    option_list = (
        make_option('--traceback', action='store_true',
            help='Print traceback on exception'),
        make_option('--no-prompt', action='store_true',
            help='Don\'t prompt for anything, use default settings'),
    )
    help = ''
    args = ''

    def usage(self, subcommand):
        """
        Return a brief description of how to use this command, by
        default from the attribute ``self.help``.

        """
        usage = '%%prog %s [options] %s' % (subcommand, self.args)
        if self.help:
            return '%s\n\n%s' % (usage, self.help)
        else:
            return usage

    def create_parser(self, prog_name, subcommand):
        """
        Create and return the ``OptionParser`` which will be used to
        parse the arguments to this command.

        """
        return OptionParser(prog=prog_name, usage=self.usage(subcommand),
            option_list=self.option_list)

    def print_help(self, prog_name, subcommand):
        """
        Print the help message for this command, derived from
        ``self.usage()``.

        """
        parser = self.create_parser(prog_name, subcommand)
        parser.print_help()

    def run_from_argv(self, argv):
        """
        Set up any environment changes requested, then run this command.

        """
        parser = self.create_parser(argv[0], argv[1])
        options, args = parser.parse_args(argv[2:])
        self.execute(*args, **options.__dict__)

    def execute(self, *args, **options):
        """
        Try to execute this command. If the command raises a
        ``CommandError``, intercept it and print it sensibly to
        stderr.

        """
        try:
            self.stdout = options.get('stdout', sys.stdout)
            self.stderr = options.get('stderr', sys.stderr)
            output = self.handle(*args, **options)
            if output:
                self.stdout.write(output)
        except CommandError, e:
            self.stderr.write('Error: %s\n' % e)
            sys.exit(1)

    def handle(self, *args, **options):
        """
        The actual logic of the command. Subclasses must implement
        this method.

        """
        raise NotImplementedError()



# Run python manage.py sync to swipe, synchronize and pre-fill the database

from django.conf import settings
from django.core.management.base import BaseCommand, CommandError
from django.core.management import call_command
import logging
from os import environ

class Command(BaseCommand):
    help = "Swipes, syncs and loads the database with fixtures."

    def handle(self, *args, **options):
        """
        Swipes, syncs and loads the database with fixtures.
        """
        try:
            env = settings.ENVIRONMENT
        except AttributeError:
            env = 'development'
        call_command('reset_db')
        call_command('syncdb')
        call_command('loaddata', env)
        logging.info("Sync success")



from django.conf.urls.defaults import *
from django.conf import settings

CONF_MODULE = '%s.conf' % settings.PROJECT_MODULE_NAME

urlpatterns = patterns('',
    (r'', include('%s.urls' % CONF_MODULE)),
    (r'', include('%s.common.urls.admin' % CONF_MODULE)),
)



# Run python manage.py require to load the requirements in a given environment

from django.conf import settings
from django.core.management.base import BaseCommand, CommandError
import logging
from os import system, environ        

class Command(BaseCommand):
    help = "Install the python requirements for a given environment."
    can_import_settings = False
    requires_model_validation = False
    def handle(self, *args, **options):
        """
        Install the python requirements for a given environment.
        """
        # assume project.settings.ENVIRONMENT else default to 'development'
        env = environ['DJANGO_SETTINGS_MODULE'].split(".")[-1]
        env = 'development' if env == 'settings' else env
        system('pip install -r ../deploy/requirements/base.txt')
        system('pip install -r ../deploy/requirements/%s.txt' % env)
        logging.info("Require success")



from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext 
from models import Post
from django.conf import settings

def show(request, post_slug):
    post = get_object_or_404(Post, slug=post_slug)
    return render_to_response('posts/show.html', 
        {'post': post}, RequestContext(request))

def index(request):
    posts = Post.objects.published()
    return render_to_response('posts/index.html', 
        {'posts': posts}, RequestContext(request))



import os.path
import sys

# Include apps on the path
PROJECT_ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), '../'))
sys.path.insert(0, os.path.join(PROJECT_ROOT, "apps"))

# URL prefix for CSS, JavaScript and images used by the Django admin.
# Use a trailing slash, and to have this be different from MEDIA_URL 
# For integration with staticfiles, this should be  STATIC_URL + 'admin/'.
# Make it different to not host on CDN
ADMIN_MEDIA_PREFIX = '/static-local/admin/'

ADMIN_MEDIA_ROOT = os.path.join(PROJECT_ROOT, 'static-local', 'admin')

# People who get code error notifications when DEBUG=False
ADMINS = (('XXXPROJECT_NAMEXXX administrator', 'XXXADMIN_EMAILXXX'),)

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3', 
        'NAME': os.path.join(PROJECT_ROOT, 'dev.db'),
    }
}

# Never deploy a site into production with DEBUG turned on!
DEBUG = True

# Address to use for various automated correspondence from the site manager(s).
DEFAULT_FROM_EMAIL = 'XXXADMIN_EMAILXXX'

# Set the subject prefix for email messages sent to admins and managers
EMAIL_SUBJECT_PREFIX = '[XXXPROJECT_NAMEXXX] '

# Maximum size (in bytes) before an upload gets streamed to the file system.
FILE_UPLOAD_MAX_MEMORY_SIZE = 5242880

# List of locations of the fixture data files, in search order
FIXTURE_DIRS = ()

# The Site Title of your Admin-Interface. Change this instead of changing index.html
GRAPPELLI_ADMIN_TITLE = "XXXPROJECT_NAMEXXX"

# A tuple of strings designating all the enabled applications
INSTALLED_APPS = (
    'grappelli',
    'django.contrib.admin',
    'django.contrib.admindocs',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.humanize',
    'django.contrib.messages',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.staticfiles',
    'ff0000', # load django-admin commands, initial fixtures, ..
)

# A tuple of IP addresses that see debug comments, when DEBUG is True
INTERNAL_IPS = ('0.0.0.0', '127.0.0.1',)

# The language code for this installation
LANGUAGE_CODE = 'en-us'

# If login is successful, the view redirects to the URL specified in next. 
# If next isn't provided, it redirects to settings.LOGIN_REDIRECT_URL 
# (which defaults to /accounts/profile/).
LOGIN_REDIRECT_URL = '/admin'

# Who should get broken-link notifications when SEND_BROKEN_LINK_EMAILS=True
MANAGERS = ADMINS

# Absolute path to the directory that holds stored files.
MEDIA_ROOT = os.path.join(PROJECT_ROOT, '..', 'uploads')

# URL that handles the media served from MEDIA_ROOT (must end in a slash)
MEDIA_URL = '/uploads/' 

# A tuple of middleware classes to use
MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'ff0000.middleware.XUACompatibleMiddleware'
)

# Number of digits grouped together on the integer part of a number
NUMBER_GROUPING = 3

# The full Python import path to the root URLconf
ROOT_URLCONF = 'urls'

# Seed for secret-key hashing algorithms
SECRET_KEY = ''

# Whether files other than .html should be returned with the correct MIME type
SET_MIMETYPE = True

# The ID of the current site in the django_site database table
SITE_ID = 1

# Absolute path to the directory where collectstatic will collect static files 
STATIC_ROOT = ''

# URL to use when referring to static files located in STATIC_ROOT
STATIC_URL = '/static/'

# Additional locations the staticfiles app will traverse
STATICFILES_DIRS = (os.path.join(PROJECT_ROOT, 'static'),)

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.contrib.auth.context_processors.auth',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.core.context_processors.static',
    'django.contrib.messages.context_processors.messages',
    'django.core.context_processors.request',
)

# Display a detailed report for any TemplateSyntaxError.
TEMPLATE_DEBUG = DEBUG

# List of locations of the template source files, in search order
TEMPLATE_DIRS = (
    os.path.join(PROJECT_ROOT, 'templates'),
)

# A tuple of template loader classes, specified as strings
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
)

# The time zone for this installation
TIME_ZONE = 'America/Los_Angeles'

# Output the "Etag" header. This saves bandwidth but slows down performance
USE_ETAGS = False

# Display numbers using a thousand separator
USE_THOUSAND_SEPARATOR = True

# Enable Django's internationalization system 
USE_I18N = True

# Display numbers and dates using the format of the current locale
USE_L10N = True



#!/usr/bin/env python
# -*- coding: utf-8 -*-
try:
    from setuptools import setup
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup

setup(
    name='django-start',
    version='0.1.10',
    description='Create a Django project based on FF0000 best practices.',
    author='RED Interactive Agency',
    author_email='claudio.baccigalupo@ff0000.com',
    url='http://github.com/ff0000/django-start/',
    packages=[
        'django_start',
        'django_start.management',
    ],
    # Note: Using MANIFEST.in instead of package_data, as it is respected
    # both by bdist and sdist, see http://stackoverflow.com/questions/6714145/
    include_package_data=True,
    exclude_package_data = { '': ['*.pyc', '.DS_Store'] },
    scripts=['bin/django-start.py'],
    classifiers=[
          'Development Status :: 3 - Alpha',
          'Environment :: Web Environment',
          'Framework :: Django',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: MIT License',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          'Topic :: Utilities'
    ]
)



# This file will contain
# - a description of this project template
# - the list of variables to be substituted
# - the commands to be launched after copying the template files (e.g. git pull)

# Also, this file will NOT be copied
import os
from random import choice
from string import ascii_lowercase, digits

def after_copy(no_prompt=False):
    """Steps to run after the templates has been copied in place."""
    # 1. Import red-boilerplate in place using git
    os.system("git init")
    os.system("git add .")
    os.system("git commit -m'Django project created with django-start'")
    os.system("git remote add -f boilerplate git://github.com/ff0000/red-boilerplate.git")
    os.system("git pull boilerplate master")
    os.system("git rm README.md")
    os.system("git mv INSTRUCTIONS.md README.md")
    os.system("git commit -m'Restored django-start README.md'")

    # 2. Replace boilerplate variables with prompt values or defaults
    placemarks = [
      ['PROJECT_NAME', 'Project Name', 'Django Project'],
      ['ADMIN_EMAIL',  'Administrator email', 'geeks@ff0000.com'],
    ]
    replace = {}
    for var, help, default in placemarks:
        placemark = '__%s__' % var
        replace[placemark] = None
        while not replace[placemark]:
            if no_prompt:
                replace[placemark] = default
            else:
                prompt = '%s [%s]: ' % (help, default)
                replace[placemark] = raw_input(prompt) or default
    # Also replace SECRET_KEY
    key_seed = ''.join([choice(ascii_lowercase + digits) for x in range(50)])
    replace['__SECRET_KEY_SEED__'] = key_seed

    # WATCH OUT!! This resets permissions!! Change with shutil

    for root, dirs, files in os.walk('.'):
        DONT_REPLACE_IN = ['.svn', '.git',]
        for folder in DONT_REPLACE_IN:
            if folder in dirs:
                dirs.remove(folder)
        for name in files:
            filepath = os.path.join(root, name)
            with open(filepath, 'r') as f:
                data = f.read()
            for old_val, new_val in replace.items():
                data = data.replace(old_val, new_val)
            with open(filepath, 'w') as f:
                f.write(data)



from django.contrib.syndication.views import Feed
from django.core.urlresolvers import reverse
from models import XXXMODEL_NAMEXXX

class XXXMODEL_NAMEXXXFeed(Feed):
    title = "Latest XXXPLURALXXX"
    description = "Latest XXXPLURALXXX"

    def link(self, obj): return reverse('XXXVAR_NAMEXXXs')

    def items(self):
        return XXXMODEL_NAMEXXX.objects.published.order_by('-published_on')[:5]

    def item_title(self, item):
        return item.title

    def item_description(self, item):
        return item.content


import os
import re
import shutil
import stat
from random import choice

def camelcase_to_underscore(name):
    s1 = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
    return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()

def copy_template(src, dest, replace=None):
    """
    Copy all files in the source path to the destination path.
    
    To replace boilerplate strings in the source data, pass a dictionary to the
    ``replace`` argument where each key is the boilerplate string and the
    corresponding value is the string which should replace it.
    
    The destination file paths are also parsed through the boilerplate
    replacements, so directories and file names may also be modified.
    
    """
    for path, dirs, files in os.walk(src):
        relative_path = path[len(src):].lstrip(os.sep)
        # Replace boilerplate strings in destination directory.
        for old_val, new_val in replace.items():
            relative_path = relative_path.replace(old_val, new_val)
        try:
            os.mkdir(os.path.join(dest, relative_path))
        except:
            # TODO: remove this
            pass
        for i, subdir in enumerate(dirs):
            if subdir.startswith('.'):
                del dirs[i]
        for filename in files:
            if (filename.startswith('djangostart') or
                filename.endswith('.pyc')):
                continue
            src_file_path = os.path.join(path, filename)
            # Replace boilerplate strings in destination filename.
            for old_val, new_val in replace.items():
                filename = filename.replace(old_val, new_val)
            dest_file_path = os.path.join(dest, relative_path, filename)
            copy_template_file(src_file_path, dest_file_path, replace)


def copy_template_file(src, dest, replace=None):
    """
    Copy a source file to a new destination file, maintaining its permissions.
    
    To replace boilerplate strings in the source data, pass a dictionary to the
    ``replace`` argument where each key is the boilerplate string and the
    corresponding value is the string which should replace it.
    
    """
    replace = replace or {}
    # Read the data from the source file.
    src_file = open(src, 'r')
    data = src_file.read()
    src_file.close()
    # Replace boilerplate strings.
    for old_val, new_val in replace.items():
        data = data.replace(old_val, new_val)

    # Generate SECRET_KEY for settings file
    secret_key = ''.join([choice('abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)') for i in range(50)])
    data = re.sub(r"(?<=SECRET_KEY = ')'", secret_key + "'", data)

    # Create the folder if it does not exist
    dest_folder = os.path.dirname(dest)
    if not os.path.exists(dest_folder):
        os.makedirs(dest_folder)

    # Write the data to the destination file.
    dest_file = open(dest, 'w')
    dest_file.write(data)
    dest_file.close()
    # Copy permissions from source file.
    shutil.copymode(src, dest)
    # Make new file writable.
    if os.access(dest, os.W_OK):
        st = os.stat(dest)
        new_permissions = stat.S_IMODE(st.st_mode) | stat.S_IWUSR
        # TODO: Remove this from here, should be managed by setuptoold
        # Make manage.py executable again:
        if os.path.basename(dest) == 'manage.py':
            new_permissions |= stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH
        os.chmod(dest, new_permissions)




from django.conf import settings
from django.conf.urls.defaults import *
from django.conf.urls.static import static
from django.contrib import admin
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.views.generic import TemplateView

admin.autodiscover()
urlpatterns = patterns('',
	(r'^admin/doc/', include('django.contrib.admindocs.urls')),
	(r'^admin/', include(admin.site.urls)),
    (r'^grappelli/', include('grappelli.urls')),
	# Homepage
	(r'^$', TemplateView.as_view(template_name='homepage.html')),
)

# Static URLs
urlpatterns += staticfiles_urlpatterns()

# Static admin URLs
urlpatterns.insert(-2, url(r'^%s(?P<path>.*)' % settings.ADMIN_MEDIA_PREFIX[1:],
    'django.views.static.serve', {'document_root': settings.ADMIN_MEDIA_ROOT}))

# Upload URLS
if settings.DEBUG:
    urlpatterns.insert(-2, url(r'^%s(?P<path>.*)' % settings.MEDIA_URL[1:],
        'django.views.static.serve', {'document_root': settings.MEDIA_ROOT}))



from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext 
from models import XXXMODEL_NAMEXXX
from django.conf import settings

def show(request, XXXVAR_NAMEXXX_slug):
    XXXVAR_NAMEXXX = get_object_or_404(XXXMODEL_NAMEXXX, slug=XXXVAR_NAMEXXX_slug)
    return render_to_response('XXXFOLDERXXX/show.html', 
        {'XXXVAR_NAMEXXX': XXXVAR_NAMEXXX}, RequestContext(request))

def index(request):
    XXXVAR_NAMEXXXs = XXXMODEL_NAMEXXX.objects.published()
    return render_to_response('XXXFOLDERXXX/index.html', 
        {'XXXVAR_NAMEXXXs': XXXVAR_NAMEXXXs}, RequestContext(request))



# Run python manage.py dump to dump a model's data into a fixture

from django.core.management.base import BaseCommand, CommandError
import logging
from os import system, environ        

class Command(BaseCommand):
    help = "Dump a model's data into a fixture."

    def handle(self, *args, **options):
        """
        Dump a model's data into a fixture.
        Uses --natural to avoid writing content_type_id which are subject
        to changes while an application is under development.
        Example: python manage.py pictures
        """
        # assume project.settings.ENVIRONMENT else default to 'development'
        env = environ['DJANGO_SETTINGS_MODULE'].split(".")[-1]
        env = 'development' if env == 'settings' else env
        # TODO: Raise error if the parameter is not passed
        model = args[0] 
        options = " --indent=4 --natural"
        output = "apps/%s/fixtures/%s.json" % (model, env)
        system('python manage.py dumpdata %s %s > %s' % 
            (model, options, output))
        logging.info("Dump success")



# Import global settings to make it easier to extend settings. 
from django.conf.global_settings import *

#==============================================================================
# Generic Django project settings
#==============================================================================

DEBUG = True
TEMPLATE_DEBUG = DEBUG

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
TIME_ZONE = 'America/Chicago'
USE_I18N = True
SITE_ID = 1

# Make this unique, and don't share it with anybody.
SECRET_KEY = ''

#==============================================================================
# Calculation of directories relative to the module location
#==============================================================================
import os
import sys
import myproject

PROJECT_DIR, PROJECT_MODULE_NAME = os.path.split(
    os.path.dirname(os.path.realpath(myproject.__file__))
)

PYTHON_BIN = os.path.dirname(sys.executable)
if os.path.exists(os.path.join(PYTHON_BIN, 'activate_this.py')):
    # Assume that the presence of 'activate_this.py' in the python bin/
    # directory means that we're running in a virtual environment. Set the
    # variable root to $VIRTUALENV/var.
    VAR_ROOT = os.path.join(os.path.dirname(PYTHON_BIN), 'var')
    if not os.path.exists(VAR_ROOT):
        os.mkdir(VAR_ROOT)
else:
    # Set the variable root to the local configuration location (which is
    # ignored by the repository).
    VAR_ROOT = os.path.join(PROJECT_DIR, PROJECT_MODULE_NAME, 'conf', 'local')

#==============================================================================
# Project URLS and media settings
#==============================================================================

ROOT_URLCONF = 'myproject.conf.urls'

LOGIN_URL = '/accounts/login/'
LOGOUT_URL = '/accounts/logout/'
LOGIN_REDIRECT_URL = '/'

MEDIA_URL = '/uploads/'
STATIC_URL = '/static/'

STATIC_ROOT = os.path.join(VAR_ROOT, 'static')
#MEDIA_ROOT = os.path.join(VAR_ROOT, 'uploads')

STATICFILES_DIRS = (
    os.path.join(PROJECT_DIR, PROJECT_MODULE_NAME, 'static'),
)

#==============================================================================
# Templates
#==============================================================================

TEMPLATE_DIRS = (
    os.path.join(PROJECT_DIR, PROJECT_MODULE_NAME, 'templates'),
)

TEMPLATE_CONTEXT_PROCESSORS += (
    # 'Custom context processors here',
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.humanize',
    'django.contrib.staticfiles',
    'south',
)
